import { request } from 'umi';

/** 获取  */
export async function GetStoreInfoPage(data) {
  return request(`/kitchen/api/Store/GetStoreList`, {
   method: 'POST',
   data: data,
   // params: { ...params },
   // ...(options || {}),
 });
}
export async function GetCokingWorkList(data) {
  return request(`/kitchen/api/select/GetCokingWorkList`);
}
/** 获取店铺上架商品  */
export async function GetStoreGoods(data) {
  return request(`​​/kitchen/api/Store/GetStoreGoods`, {
    method: 'POST',
    data: data,
    // params: { ...params },

    // ...(options || {}),
  });
}

/** 启用停用  */
export async function UpdateStoreGoodsStatusAsync(data) {
  return request(`/kitchen/api/Store/UpdateStoreGood`, {
    method: 'put',
    data: data,
  });
}
/**商品估清 */
export async function stopgoods(data) {
  return request(`/kitchen/api/goods/stopgoods`, {
    method: 'POST',
    data: data,
  });
}
/** 修改  */
export async function UpdateStoreGoods(data) {
  return request(`/kitchen/api/Store/UpdateStoreGood`, {
    method: 'put',
    data: data,
    // params: { ...params },
    // ...(options || {}),
  });
}
/** 新增  */
export async function AddStoreGood(data) {
  return request(`/kitchen/api/store-info/store-good`, {
    method: 'POST',
    data: data,
    // params: { ...params },
    // ...(options || {}),
  });
}



/** 删除上架商品  */
export async function DelStoreGoods(data) {
  return request(`/kitchen/api/store-info/del-store-good`, {
    method: 'POST',
    data: data,
    // params: { ...params },
    // ...(options || {}),
  });
}

/** 获取商品  sdsa GET /kitchen/api/rule */
export async function getGoods() {
  var data = { current: 1, pageSize: 1000, goods_Enable: 0 };
  return request(`/kitchen/api/goods/goodss`, {
    method: 'Post',
    data: data,
    // params: { ...params },
    // ...(options || {}),
  });
}

export function StoreGoodsAllUpdate(data) {
  return request(`/kitchen//api/Store/StoreGoodsAllUpdate`, {
    method: 'post',
    data: data,
  });
}


export function GetRequestLogPageAsync(data) {
  return request(`/kitchen/api/log/request-log-page`, {
    method: 'post',
    data: data,
  });
}
